@@ -5,12 +5,13 @@ use vars qw($VERSION @ISA);
 use DynaLoader;
 
 @ISA = qw(DynaLoader);
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 __PACKAGE__->bootstrap($VERSION);
 
 sub import {
     *CORE::GLOBAL::symlink = __PACKAGE__->can('symlink');
+    *CORE::GLOBAL::readlink = __PACKAGE__->can('readlink');
 }
 
 1;
@@ -23,18 +24,23 @@ Win32::Symlink - Symlink support on Windows
 
 =head1 VERSION
 
-This document describes version 0.03 of Win32::Symlink, released
-September 25, 2004.
+This document describes version 0.04 of Win32::Symlink, released
+October 10, 2004.
 
 =head1 SYNOPSIS
 
     use Win32::Symlink;
-    symlink( 'from' => 'to' );
+
+    # Assuming D: is a NTFS volume...
+    mkdir 'D:\from';
+    symlink( 'D:\from' => 'D:\to' );
+    print readlink( 'D:\to' ); # 'D:\from'
+    rmdir 'D:\from', 'D\to';
 
 =head1 DESCRIPTION
 
-This module implements the built-in C<symlink> function for Microsoft Windows.
-Currently, it only works on NTFS filesystems.
+This module implements the built-in C<symlink> and C<readlink> functions for
+Microsoft Windows.  Currently, it only works on NTFS filesystems.
 
 =head1 SEE ALSO
 
